"use client";

import React, { ReactElement, useState } from "react";
import { Button } from "@/app/components/ui/button";
import { Dialog, DialogContent, DialogTitle, DialogTrigger } from "@/app/components/ui/dialog";
import { DocsContentMetadata } from "@/app/common/documentation";
import { DocumentationPages } from "@/app/components/docs/documentation-pages";
import { SearchIcon } from "lucide-react";

export function Search(): ReactElement {
  /**
   * The pages that were found
   */
  const [pages, setPages] = useState<DocsContentMetadata[] | undefined>(undefined);
  const [continueTyping, setContinueTyping] = useState<boolean>(false);

  /**
   * Search the documentation
   * for the given query.
   *
   * @param query the query to search for
   */
  async function searchDocs(query: string): Promise<void> {
    // Don't bother searching if the query is less than 3 characters
    if (query.length < 3) {
      if (query.length > 0) {
        setContinueTyping(true);
      } else {
        setContinueTyping(false);
      }
      return setPages(undefined);
    }

    // Attempt to search for the query
    const response = await fetch(`/api/docs/search?query=${query}`);
    const pages: DocsContentMetadata[] = await response.json();
    setPages(pages);
  }

  return (
    <div className="w-full md:w-[250px] min-h-fit h-fit bg-card rounded-lg p-3">
      <div className="flex flex-col w-full">
        <Dialog>
          <DialogTrigger asChild>
            <Button className="flex items-center gap-1">
              <SearchIcon width={16} height={16} />
              <p>Search</p>
            </Button>
          </DialogTrigger>
          <DialogContent className="w-screen md:w-[600px]">
            <DialogTitle>Search Documentation</DialogTitle>
            <input
              type="text"
              placeholder="Query..."
              className="w-full p-2 border border-border rounded-lg focus:outline-none focus:ring-2 focus:border-ring"
              onChange={event => searchDocs(event.target.value)}
            />

            {!pages && continueTyping && <p>Continue typing...</p>}

            <DocumentationPages pages={pages} />
          </DialogContent>
        </Dialog>
      </div>
    </div>
  );
}
